==> dbt-materialize-1.0.1.post1.tar.gz: dbt-materialize-1.0.1.post1/dbt/include/materialize/macros/materializations/index.sql <==
-- Copyright Materialize, Inc. and contributors. All rights reserved.
--
-- Licensed under the Apache License, Version 2.0 (the "License");
-- you may not use this file except in compliance with the License.
-- You may obtain a copy of the License in the LICENSE file at the
-- root of this repository, or online at
--
--     http://www.apache.org/licenses/LICENSE-2.0
--
-- Unless required by applicable law or agreed to in writing, software
-- distributed under the License is distributed on an "AS IS" BASIS,
-- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-- See the License for the specific language governing permissions and
-- limitations under the License.

{% materialization index, adapter='materialize' %}
  {%- set identifier = model['alias'] -%}
  {%- set target_relation = api.Relation.create(identifier=identifier,
                                                schema=schema,
                                                database=database,
                                                type='index') -%}

  {% set index_name %}
      {{ mz_generate_name(identifier) }}
  {% endset %}
  {{ materialize__drop_index(index_name) }}

  {{ run_hooks(pre_hooks, inside_transaction=False) }}

  {% call statement('main') -%}
    {{ materialize__create_arbitrary_object(sql) }}
  {%- endcall %}

  {% do persist_docs(target_relation, model) %}

  {{ run_hooks(post_hooks, inside_transaction=False) }}

  {{ return({'relations': [target_relation]}) }}
{% endmaterialization %}

==> dbt-materialize-1.0.5.tar.gz: dbt-materialize-1.0.5/dbt/include/materialize/macros/materializations/index.sql <==
-- Copyright Materialize, Inc. and contributors. All rights reserved.
--
-- Licensed under the Apache License, Version 2.0 (the "License");
-- you may not use this file except in compliance with the License.
-- You may obtain a copy of the License in the LICENSE file at the
-- root of this repository, or online at
--
--     http://www.apache.org/licenses/LICENSE-2.0
--
-- Unless required by applicable law or agreed to in writing, software
-- distributed under the License is distributed on an "AS IS" BASIS,
-- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-- See the License for the specific language governing permissions and
-- limitations under the License.

{% materialization index, adapter='materialize' %}
    {{ exceptions.warn(
        """
        The custom index materialization is deprecated and will be removed in a future release of dbt-materialize.
        Please use the `indexes` config instead:

        e.g.
        {{ config(
            materialized = 'view',
            indexes = [ {'columns': ['column_a']} ]
        )}}

        Documentation for indexes in Materialize can be found in: https://materialize.com/docs/sql/create-index
        """
    )}}
  {%- set identifier = model['alias'] -%}
  {%- set target_relation = api.Relation.create(identifier=identifier,
                                                schema=schema,
                                                database=database,
                                                type='index') -%}

  {% set index_name %}
      {{ mz_generate_name(identifier) }}
  {% endset %}
  {{ materialize__drop_index(index_name) }}

  {{ run_hooks(pre_hooks, inside_transaction=False) }}
  {{ run_hooks(pre_hooks, inside_transaction=True) }}

  {% call statement('main') -%}
    {{ materialize__create_arbitrary_object(sql) }}
  {%- endcall %}

  {% do persist_docs(target_relation, model) %}

  {{ run_hooks(post_hooks, inside_transaction=False) }}
  {{ run_hooks(post_hooks, inside_transaction=True) }}

  {{ return({'relations': [target_relation]}) }}
{% endmaterialization %}
